summaryrefslogtreecommitdiff
path: root/vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php')
-rw-r--r--vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php b/vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php
index 91e65e2d70..e69961b7de 100644
--- a/vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php
+++ b/vendor/symfony/http-kernel/Exception/TooManyRequestsHttpException.php
@@ -21,11 +21,11 @@ class TooManyRequestsHttpException extends HttpException
/**
* @param int|string $retryAfter The number of seconds or HTTP-date after which the request may be retried
* @param string $message The internal exception message
* @param \Exception $previous The previous exception
* @param int $code The internal exception code
* @param array $headers
*/
- public function __construct($retryAfter = null, string $message = null, \Exception $previous = null, ?int $code = 0, array $headers = [])
+ public function __construct($retryAfter = null, string $message = null, \Throwable $previous = null, ?int $code = 0, array $headers = [])
{
if ($retryAfter) {
$headers['Retry-After'] = $retryAfter;
@@ -21,11 +21,11 @@ class TooManyRequestsHttpException extends HttpException
* @param int|string $retryAfter The number of seconds or HTTP-date after which the request may be retried
* @param string $message The internal exception message
- * @param \Exception $previous The previous exception
+ * @param \Throwable $previous The previous exception
* @param int $code The internal exception code
* @param array $headers